@@ -122,7 +122,7 @@ enum {
         PROP_SWITCH_ENABLED
 };
 
-static guint lock_plug_signals [LAST_SIGNAL];
+static guint lock_plug_signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GSLockPlug, gs_lock_plug, GTK_TYPE_PLUG)
 
@@ -144,17 +144,19 @@ gs_lock_plug_style_set (GtkWidget *widget,
         gtk_container_set_border_width (GTK_CONTAINER (plug->priv->auth_action_area), 0);
         gtk_box_set_spacing (GTK_BOX (plug->priv->auth_action_area), 6);
         gtk_box_set_homogeneous (GTK_BOX (plug->priv->auth_action_area), FALSE);
-        gtk_button_box_set_child_non_homogeneous (plug->priv->auth_action_area, plug->priv->auth_switch_button, TRUE);
+        gtk_button_box_set_child_non_homogeneous (GTK_BUTTON_BOX (plug->priv->auth_action_area), plug->priv->auth_switch_button, TRUE);
 }
 
 static gboolean
 process_is_running (const char * name)
 {
         int num_processes;
-        char * command = g_strdup_printf ("pidof %s | wc -l", name);
+        gchar *command = g_strdup_printf ("pidof %s | wc -l", name);
         FILE *fp = popen(command, "r");
         fscanf(fp, "%d", &num_processes);
         pclose(fp);
+        g_free (command);
+
         if (num_processes > 0) {
                 return TRUE;
         } else {
@@ -189,7 +191,7 @@ do_user_switch (GSLockPlug *plug)
                         gs_debug ("Unable to start MDM greeter: %s", error->message);
                         g_error_free (error);
                 }
-        } else if (process_is_running ("gdm")) {
+        } else if (process_is_running ("gdm") || process_is_running("gdm3")) {
                 command = g_strdup_printf ("%s %s",
                                            GDM_FLEXISERVER_COMMAND,
                                            GDM_FLEXISERVER_ARGS);
@@ -326,7 +328,7 @@ dialog_timed_out (GSLockPlug *plug)
 
         remove_response_idle (plug);
 
-        plug->priv->response_idle_id = g_timeout_add (2000,
+        plug->priv->response_idle_id = g_timeout_add_seconds (2,
                                                       (GSourceFunc)response_cancel_idle_cb,
                                                       plug);
         return FALSE;
@@ -405,6 +407,8 @@ gs_lock_plug_get_text (GSLockPlug *plug,
 
         if (text != NULL) {
                 *text = local_text;
+        } else {
+                g_free (local_text);
         }
 }
 
@@ -1118,6 +1122,7 @@ gs_lock_plug_set_switch_enabled (GSLockPlug *plug,
         if (switch_enabled) {
                 if (process_is_running ("mdm") ||
                     process_is_running ("gdm") ||
+                    process_is_running ("gdm3") ||
                     g_getenv("XDG_SEAT_PATH")) {
                         gtk_widget_show (plug->priv->auth_switch_button);
                 } else {
@@ -1639,7 +1644,7 @@ switch_user_button_clicked (GtkButton  *button,
 
         gs_lock_plug_set_sensitive (plug, FALSE);
 
-        plug->priv->response_idle_id = g_timeout_add (2000,
+        plug->priv->response_idle_id = g_timeout_add_seconds (2,
                                                       (GSourceFunc)response_cancel_idle_cb,
                                                       plug);
 
